@@ -25,6 +25,7 @@ pub struct PyArgs {
     pub sort: Option<PySortMode>,
     pub max_count: Option<u64>,
     pub line_number: Option<bool>,
+    pub multiline: Option<bool>,
 }
 
 #[pymethods]
@@ -43,6 +44,7 @@ impl PyArgs {
         sort=None,
         max_count=None,
         line_number=None,
+        multiline=None,
     ))]
     fn new(
         patterns: Vec<String>, 
@@ -57,6 +59,7 @@ impl PyArgs {
         sort: Option<PySortMode>,
         max_count: Option<u64>,
         line_number: Option<bool>,
+        multiline: Option<bool>,
     ) -> Self {
         PyArgs {
             patterns,
@@ -71,6 +74,7 @@ impl PyArgs {
             sort,
             max_count,
             line_number,
+            multiline,
         }
     }
 }
@@ -190,6 +194,10 @@ fn pyargs_to_hiargs(py_args: &PyArgs, mode: lowargs::Mode) -> anyhow::Result<HiA
         low_args.context_separator = lowargs::ContextSeparator::new(&sep).unwrap();
     }
 
+    if let Some(multiline) = py_args.multiline {
+        low_args.multiline = multiline;
+    }
+
     HiArgs::from_low_args(low_args)
 }
 
@@ -209,6 +217,7 @@ fn pyargs_to_hiargs(py_args: &PyArgs, mode: lowargs::Mode) -> anyhow::Result<HiA
     sort=None,
     max_count=None,
     line_number=None,
+    multiline=None,
 ))]
 pub fn py_search(
     py: Python<'_>,
@@ -224,6 +233,7 @@ pub fn py_search(
     sort: Option<PySortMode>,
     max_count: Option<u64>,
     line_number: Option<bool>,
+    multiline: Option<bool>,
 ) -> PyResult<Vec<String>> {
     py.allow_threads(|| {
         let py_args = PyArgs {
@@ -239,6 +249,7 @@ pub fn py_search(
             sort,
             max_count,
             line_number,
+            multiline,
         };
 
         let args_result = pyargs_to_hiargs(&py_args, lowargs::Mode::default());
@@ -332,6 +343,7 @@ fn py_search_impl(args: &HiArgs) -> anyhow::Result<Vec<String>> {
     sort=None,
     max_count=None,
     line_number=None,
+    multiline=None,
 ))]
 pub fn py_files(
     py: Python<'_>,
@@ -347,6 +359,7 @@ pub fn py_files(
     sort: Option<PySortMode>,
     max_count: Option<u64>,
     line_number: Option<bool>,
+    multiline: Option<bool>,
 ) -> PyResult<Vec<String>> {
     py.allow_threads(|| {
         let py_args = PyArgs {
@@ -362,6 +375,7 @@ pub fn py_files(
             sort,
             max_count,
             line_number,
+            multiline,
         };
 
         let args_result = pyargs_to_hiargs(&py_args, lowargs::Mode::Files);
